==> webpdf-wsclient-10.0.1-sources.jar: net/webpdf/wsclient/schema/operation/ConverterOfficeType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p165541_="https://jakarta.ee/xml/ns/jaxb" xmlns:p356920_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;&#13;
 *                     Defines the settings to be used when converting Office documents (e.g., docx documents).&#13;
 *                     &lt;p&gt;&lt;b&gt;Important:&lt;/b&gt;&#13;
 *                         Currently only the integrated Word document converter for docx files is supported&#13;
 *                     &lt;/p&gt;&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for ConverterOfficeType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="ConverterOfficeType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <all>
 *         <element name="word" type="{http://schema.webpdf.de/1.0/operation}ConverterOfficeWordType" minOccurs="0"/>
 *       </all>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ConverterOfficeType", propOrder = {

})
public class ConverterOfficeType {

    protected ConverterOfficeWordType word;

    /**
     * Gets the value of the word property.
     * 
     * @return
     *     possible object is
     *     {@link ConverterOfficeWordType }
     *     
     */
    public ConverterOfficeWordType getWord() {
        return word;
    }

    /**
     * Sets the value of the word property.
     * 
     * @param value
     *     allowed object is
     *     {@link ConverterOfficeWordType }
     *     
     */
    public void setWord(ConverterOfficeWordType value) {
        this.word = value;
    }

    public boolean isSetWord() {
        return (this.word!= null);
    }

}

==> webpdf-wsclient-10.0.2-sources.jar: net/webpdf/wsclient/schema/operation/ConverterOfficeType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p532746_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p882137_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;&#13;
 *                     Defines the settings to be used when converting Office documents (e.g., docx documents).&#13;
 *                     &lt;p&gt;&lt;b&gt;Important:&lt;/b&gt;&#13;
 *                         Currently only the integrated Word document converter for docx files is supported&#13;
 *                     &lt;/p&gt;&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for ConverterOfficeType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="ConverterOfficeType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <all>
 *         <element name="word" type="{http://schema.webpdf.de/1.0/operation}ConverterOfficeWordType" minOccurs="0"/>
 *       </all>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ConverterOfficeType", propOrder = {

})
public class ConverterOfficeType {

    protected ConverterOfficeWordType word;

    /**
     * Gets the value of the word property.
     * 
     * @return
     *     possible object is
     *     {@link ConverterOfficeWordType }
     *     
     */
    public ConverterOfficeWordType getWord() {
        return word;
    }

    /**
     * Sets the value of the word property.
     * 
     * @param value
     *     allowed object is
     *     {@link ConverterOfficeWordType }
     *     
     */
    public void setWord(ConverterOfficeWordType value) {
        this.word = value;
    }

    public boolean isSetWord() {
        return (this.word!= null);
    }

}
